@@ -14,7 +14,7 @@ n11<- obs[1]
 n10<- obs[2]
 n01<- obs[3]
 n00<- obs[4]
-  return( t = n11/(n11+n01), u = n10/(n10+n00) )
+  return( list( t = n11/(n11+n01), u = n10/(n10+n00) ))
 } else {
 A   <- table(data.frame( obs, gold.standard) )
 n11 <- A[2,2]
@@ -22,7 +22,7 @@ n00 <- A[1,1]
 n10 <- A[2,1]
 n01 <- A[1,2]
 
-return( t = n11/(n11+n01), u = n10/(n10+n00) )
+return( list(t = n11/(n11+n01), u = n10/(n10+n00) ) )
 }
 
 }
